@@ -4,7 +4,7 @@ use ouroboros::self_referencing;
 struct S {
     #[borrows(a)]
     b: &'this i32,
-    a: Box<i32>,
+    a: i32,
 }
 
 fn main() { }
